"""Bzr configurator library"""

import os
import sys

# set-up logging level
import logging
if os.environ.get('BZR_CONFIG_DEBUG'):
    logging.basicConfig(level=logging.DEBUG)

# install gettext
import gettext

if sys.platform == 'win32':
    for i in ('LANGUAGE','LC_ALL','LC_MESSAGES','LANG'):
        if os.environ.get(i):
            break
    else:
        lang = None
        import locale
        try:
            import ctypes
        except ImportError:
            # use only user's default locale
            lang = locale.getdefaultlocale()[0]
        else:
            # using ctypes to determine all locales
            lcid_user = ctypes.windll.kernel32.GetUserDefaultLCID()
            lcid_system = ctypes.windll.kernel32.GetSystemDefaultLCID()
            if lcid_user != lcid_system:
                lcid = [lcid_user, lcid_system]
            else:
                lcid = [lcid_user]
            lang = [locale.windows_locale.get(i) for i in lcid]
            lang = ':'.join([i for i in lang if i])
        # set lang code for gettext
        if lang:
            os.environ['LANGUAGE'] = lang
            logging.debug('set LANGUAGE=%s', lang)

d = os.path.join(os.path.realpath(os.path.dirname(sys.argv[0])), 'locale')
if not os.path.isdir(d):
    d = None

gettext.install('bzr-config', d, True)
logging.debug('gettext.install from %r', d)


def main(args_list=None):
    from bzrconf.bzrlib_importer import bzrlib
    from bzrconf.gui import Application
    from bzrconf import model

##    print [i for i in dir(bzrlib.plugins) if not i.startswith('__')]

    gm = model.GeneralModel()
    am = model.AliasesModel()

    # create GUI main window
    app = Application([gm, am])

    # mainloop of GUI
    app.run()

    return 0
