"""Tkinter GUI"""

__all__ = ['Application', 'showerror']


import os
import sys
from Tkinter import *
import tkMessageBox

from buttons import ButtonsPanel
from page_selector import PageSelector
from panels import *


class Application:

    def __init__(self, models=None):
        # create root window
        self.root = Tk()
        self.root.title(_('Bazaar configuration'))
        self._set_icon()

        # create main widgets
        self.sa = Frame(self.root)
        self.sp = create_switched_panels(self.sa, models)

        if models is None:
            pages = ["General", "Aliases", "Plugins"]
        else:
            pages = [i.name for i in models]
        self.ps = PageSelector(self.root, pages, self.sp.switch)

        self.bp = ButtonsPanel(self.root, self.sp.save, self.sp.reset)

        # pack widgets
        self.ps.pack(side=TOP, anchor=W)
        self.bp.pack(side=BOTTOM, anchor=S, fill=X)
        self.sa.pack(fill=BOTH, expand=YES)

    def run(self):
        self.root.mainloop()

    def _set_icon(self):
        dirs = (os.path.dirname(os.path.realpath(sys.argv[0])),
                os.path.join(sys.prefix,'share'))
        if sys.platform in ('win32', 'cygwin'):
            ico = './icons/olive-branches.ico'
            for d in dirs:
                fn = os.path.join(d, ico)
                if os.path.isfile(fn):
                    self.root.iconbitmap(fn)
                    break
        elif sys.platform == 'linux2':
            ico = './icons/olive-branches.gif'
            for d in dirs:
                fn = os.path.join(d, ico)
                if os.path.isfile(fn):
                    self._img = PhotoImage(file=fn)
                    self.root.tk.call('wm', 'iconphoto', self.root._w, self._img)
                    break
        else:
            # don't know how to set icon on your platform
            pass
#/class Application


def showerror(title, message):
    tkMessageBox.showerror(title, message)
