"""Aliases panel"""

__all__ = ['AliasesPanel']

import logging
from Tkinter import *

from alias_dialog import AliasDialog
from multilist import MultiListbox


class AliasesPanel(Frame):

    def __init__(self, parent, model):
        Frame.__init__(self, parent, relief=GROOVE, borderwidth=2)
        self.model = model
        if model is None:
            Label(self, text='Aliases').pack()
        else:
            text_alias = ' %s ' % _('Alias')
            text_command = ' %s ' % _('Command')
            lalias = len(text_alias)
            lcommand = len(text_command)
            for a in self.model:
                lalias = max(lalias, len(a.alias))
                lcommand = max(lcommand, len(a.command))
            if lalias+lcommand < 58:
                lcommand = 58 - lalias
            self.mlb = AliasMultiListbox(self, ((text_alias, lalias),
                                                (text_command, lcommand),
                                               ))
            self.mlb.pack(expand=YES, fill=BOTH, padx=5, pady=5)
            self.mlb.model = model
            self._setData()
            # control buttons
            bf = Frame(self)
            btns = [(_('Add'), self.mlb.onInsert),
                    (_('Remove'), self.mlb.onDelete),
                    (_('Change'), self.mlb.onEnter)]
            w = max(len(t) for t,f in btns) + 4
            for ix, (t, f) in enumerate(btns):
                Button(bf, text=t, width=w, command=f).grid(column=ix, row=0,
                                                              padx=10, pady=4)
            bf.pack(side=BOTTOM, fill=X)

    def _setData(self):
        for a in self.model:
            self.mlb.insert(END, (' %s ' % a.alias,
                                  ' %s ' % a.command))
        self.mlb.insert(END, (' ', ' '))

    def reset(self):
        self.mlb.delete(0, END)
        self._setData()

    def save(self):
        pass


class AliasMultiListbox(MultiListbox):

    def _new_alias(self, ix):
        """Add new alias at index ix"""
        dialog = AliasDialog(self, _('New alias'), '', '')
        result = dialog.result
        if result is not None:
            alias, command = result
            # update model
            self.model.insert(ix, (alias, command))
            # update gui
            self.insert(ix, (' %s ' % alias,
                             ' %s ' % command))
            self.selection_clear(0, END)
            self.selection_set(ix)

    def onEnter(self):
        """Edit existing or add new alias"""
        ix = self.curselection()
        if ix >= 0 and ix < self.size()-1:
            # change existing alias
            alias, command = self.get(ix)
            alias = alias.strip()
            command = command.strip()
            dialog = AliasDialog(self, _('Change alias'),
                                 alias, command)
            result = dialog.result
            if result is not None:
                alias, command = result
                # update model
                self.model[ix] = (alias, command)
                # update gui
                self.delete(ix)
                self.insert(ix, (' %s ' % alias,
                                 ' %s ' % command))
                self.selection_set(ix)
        else:
            # add new alias
            self._new_alias(ix=self.size()-1)

    def onInsert(self):
        ix = self.curselection()
        if ix == -1:
            ix = self.size()-1
        self._new_alias(ix)

    def onDelete(self):
        ix = self.curselection()
        if ix >= 0 and ix < self.size()-1:
            # update model
            del self.model[ix]
            # update gui
            self.delete(ix)
            self.selection_set(ix)
