"""General options property panel"""

__all__ = ['GeneralPropertiesPanel']

from Tkinter import *
from tkMessageBox import showerror

from property_panel import *


KLASS_MAP = {'entry': PropertyEntry,
             'entry2': None,
             'filename': PropertyEntryFile,
             'editor_disabled': None,       # <<< see below
                                            #     PropertyLabelEditorDisabled
             'group': PropertyGroupWithChangeDialog,
             'spacer': PropertySpacer,
            }


class GeneralPropertiesPanel(PropertyPanel):

    def __init__(self, parent, model=None):
        self.model = model
        if model is None:
            Frame.__init__(self, parent)
            Label(self, text='General').pack()
        else:
            properties = []
            for i in model:
                name = i.name
                value = i.value
                kind = i.kind
                variants = i.variants

                klass = KLASS_MAP[kind]

                if kind == 'entry2':
                    # specail hack
                    name1, name2 = name
                    value1, value2 = value
                    klass = KLASS_MAP['entry']
                    properties.append((name1, klass, value1))
                    properties.append((name2, klass, value2))
                elif kind == 'group':
                    properties.append((name, klass, variants, value))
                else:
                    properties.append((name, klass, value))
            PropertyPanel.__init__(self, properties, parent)

    def save(self):
        model = self.model
        if model is not None:
            for i in model:
                name = i.name
                kind = i.kind
                if kind == 'entry2':
                    name1, name2 = name
                    value1 = getattr(self.property, name1)
                    value2 = getattr(self.property, name2)
                    i.value = (value1, value2)
                elif kind != 'spacer':
                    i.value = getattr(self.property, name)

    def reset(self):
        model = self.model
        if model is not None:
            for i in model:
                name = i.name
                value = i.value
                kind = i.kind
                if kind == 'entry2':
                    name1, name2 = name
                    value1, value2 = value
                    setattr(self.property, name1, value1)
                    setattr(self.property, name2, value2)
                elif kind != 'spacer':
                    setattr(self.property, name, value)
#/class GeneralPropertiesPanel


class PropertyLabelEditorDisabled(PropertyLabelWithSelect):
    """Disabled editor entry because $BZR_EDITOR is set"""

    def __init__(self, parent, default=None):
        PropertyLabelWithSelect.__init__(self, parent, default)
        self._label.configure(width=40)

    def onSelect(self):
        showerror(_('Unable to change editor'),
                  _('Environment variable BZR_EDITOR is set.\n'
                  'Value of this variable overrides settings in bazaar.conf'))
#/class PropertyLabelEditorDisabled


# update map of property classes
KLASS_MAP['editor_disabled'] = PropertyLabelEditorDisabled
