"""Panels set"""

def create_panels(parent, models):
    """Create our set of panels and return panel set
    as list of 2-tuple (panel_name, panel_frame)

    @param  parent:     parent for the new frames
    @param  models:     list of model objects
    """
    from aliases import AliasesPanel
    from general import GeneralPropertiesPanel
    from plugins import PluginsPanel

    PANEL_MAP = {'General': GeneralPropertiesPanel,
                 'Aliases': AliasesPanel,
                 'Plugins': PluginsPanel,
                }

    if models is None:
        from bzrconf import model
        gm = model.GeneralModel()

        g = GeneralPropertiesPanel(parent, gm)
        a = AliasesPanel(parent)
        p = PluginsPanel(parent)

        return [('General', g),
                ('Aliases', a),
                ('Plugins', p),
               ]
    else:
        panels = []
        for m in models:
            name = m.name
            obj = PANEL_MAP[name](parent, m)
            panels.append((name, obj))
        return panels


def create_switched_panels(parent, models):
    from switch_panels import PanelSwitcher

    return PanelSwitcher(create_panels(parent, models))
