"""Switch panels widget"""

__all__ = ['PanelSwitcher']

import logging
from Tkinter import *


class PanelSwitcher:

    def __init__(self, panels):
        """@param   panels:     list of 2-tuple (panel_name, panel_frame)
        """
        self._previous = None
        self._panels = {}
        for name, frame in panels:
            self._panels[name] = frame
        self.switch(panels[0][0])

    def switch(self, name):
        if name in self._panels:
            if self._previous is not None:
                self._previous.pack_forget()
            frame = self._panels[name]
            frame.pack(fill=BOTH, expand=YES, ipadx=5, ipady=5)
            frame.update()
#            logging.debug(`(frame.winfo_reqwidth(),frame.winfo_reqheight())`)
#            logging.debug(`(frame.winfo_width(),frame.winfo_height())`)
            self._previous = frame

    def save(self):
        for name in self._panels:
            panel = self._panels[name]
            panel.save()
            model = panel.model
            if model is not None:
                model.save()

    def reset(self):
        for name in self._panels:
            panel = self._panels[name]
            model = panel.model
            if model is not None:
                model.reset()
            panel.reset()
