#!/usr/bin/python

from distutils.core import setup
import glob
import os
import sys


META_INFO = {
        'name':         'bzr-config',
        'version':      '0.17.0',
        'description':  'Bazaar Configuration GUI Utility',
        'author':       'Alexander Belchenko',
        'author_email': 'bialix@ukr.net',
        'license':      'GNU GPL v2',
        'classifiers':  [
            'Development Status :: 3 - Alpha',
            'Environment :: Win32 (MS Windows)',
            'Environment :: X11 Applications',
            'Intended Audience :: Developers',
            'Intended Audience :: End Users/Desktop',
            'License :: OSI Approved :: GNU General Public License (GPL)',
            'Natural Language :: English',
            'Natural Language :: German',
            'Natural Language :: Polish',
            'Natural Language :: Brazilian Portuguese',
            'Natural Language :: Russian',
            'Natural Language :: Ukranian',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: POSIX',
            'Programming Language :: Python',
            'Topic :: Software Development :: Version Control',
            ],
        }

SOURCES = {'packages': ['bzrconf',
                        'bzrconf.gui',
                        'bzrconf.gui.tkgui',
                       ],
          }


def mo_files(target_prefix='share'):
    """Return collection of mo files to install"""
    files = []
    if not os.path.isdir('locale'):
        return files
    for i in os.listdir('locale'):
        src_dir = os.path.join('locale', i, 'LC_MESSAGES')
        source = os.path.join(src_dir, META_INFO['name']+'.mo')
        target = os.path.join(target_prefix, src_dir)
        files.append((target, [source]))
    return files
#/def mo_files

def icons(target_prefix='share'):
    """Return collection of icons files to install"""
    return [(os.path.join(target_prefix, 'icons'),
             glob.glob('icons/*'))]
#/def icons


if 'py2exe' in sys.argv:
    # py2exe setup
    import py2exe

    target = py2exe.build_exe.Target(
                    script = "bzr-config.py",
                    dest_base = "bzr-config",
                    icon_resources = [(0,'icons/olive-branches.ico')],
                    name = META_INFO['name'],
                    version = META_INFO['version'],
                    description = META_INFO['description'],
                    company_name = META_INFO['author'],
                    copyright = 'Alexander Belchenko, 2007',
                    )

    options_list = {"py2exe": {"packages": SOURCES['packages'],
                               "excludes": ["bzrlib"],
                               "dist_dir": "bzr-config.exe",
                              },
                   }
    setup(options = options_list,
          data_files = icons('') + mo_files(''),
          windows = [target],
          zipfile = 'lib/library.zip')

elif 'bdist_wininst' in sys.argv:
    ARGS = {'scripts': ['bzr-config.py',
                        'extras/installer/bzrconf-postinstall.py'],
            'data_files': icons() + mo_files(),
           }
    ARGS.update(META_INFO)
    ARGS.update(SOURCES)

    setup(**ARGS)

else:
    # plain setup
    CMDCLASS = {}
    try:
        from extras.build_mo import build_mo
        CMDCLASS['build_mo'] = build_mo
    except ImportError:
        pass

    ARGS = {'scripts': ['bzr-config.py'],
            'data_files': icons() + mo_files(),
           }
    ARGS.update(META_INFO)
    ARGS.update(SOURCES)
    if CMDCLASS:
        ARGS.update({'cmdclass': CMDCLASS})

    setup(**ARGS)
